shipami
=======

|Version|

CLI tool to manage AWS AMI and Marketplace


.. |Version| image:: http://img.shields.io/pypi/v/shipami.svg?style=flat
    :target: https://pypi.python.org/pypi/shipami/
    :alt: Version

Install
-------

.. code-block:: sh

    $ pip install shipami
